Module chunk

Module chunk 

Compatibility namespace kept private to the compiler implementation while the public contract calls this immutable structure a program image.

Re-exports

pub use crate::Op;
pub use crate::program::*;